<?php
/**
 * Theme base class
 * 
 * @package 	TP Framework
 * @subpackage 	tp-framework\includes\classes
 * @since 		1.0.0
 * @author 		ThemePlugger <themeplugger@gmail.com>
 * @link 		http://themeplugger.com
 * @license 	GNU General Public License, version 3
 * @copyright 	© 2014 ThemePlugger
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

if ( ! class_exists( 'TP_Base_Theme' ) ) :

/**
 * TP Base Theme
 * 
 * @todo Test load_textdomain()
 * @todo Test WPMU
 * @todo Test on parent and child theme
 * 
 * @since 1.0.0
 * 
 * @abstract
 */
abstract class TP_Base_Theme extends TP_Base implements TP_Interface_Singleton {
	
	/**
	 * Is child theme
	 * 
	 * @since 1.0.0
	 * 
	 * @var boolean
	 */
	public $is_child_theme = false;
	
	
	/** Setup methods **************************************************/
	
	/**
	 * Registers theme activation hook
	 * 
	 * @since 1.0.0
	 * 
	 * @param string 	$tag 			'after_switch_theme'
	 * @param string 	$function 		array( $this, 'activate' )
	 * @param int 	 	$priority 		10
	 * @param int 	 	$accepted_args 	2
	 */
	protected function setup_activation( $tag = 'after_switch_theme', $function = '', $priority = 10, $accepted_args = 2 ) {
		add_action( $tag ? $tag : 'after_switch_theme', $function ? $function : array( $this, 'activate' ), $priority, $accepted_args );
	}
	
	/**
	 * Registers theme activation hook
	 * 
	 * @since 1.0.0
	 * 
	 * @param string 	$tag 			'switch_theme'
	 * @param string 	$function 		array( $this, 'deactivate' )
	 * @param int 	 	$priority 		10
	 * @param int 	 	$accepted_args 	2
	 */
	protected function setup_deactivation( $tag = 'switch_theme', $function = '', $priority = 10, $accepted_args = 2 ) {
		add_action( $tag ? $tag : 'switch_theme', $function ? $function : array( $this, 'deactivate' ), $priority, $accepted_args );
	}
	
	
	/** Hook methods **************************************************/
	
	/**
	 * Load text domain for translation
	 * 
	 * @since 1.0.0
	 */
	public function load_textdomain() {
		$loaded = false;
		
		// Child theme @TODO
		if ( is_child_theme() ) {
			$loaded = load_child_theme_textdomain( $this->textdomain, $this->languages_dir );
		}
		
		// Parent theme
		if ( $loaded == false ) 
			load_theme_textdomain( $this->textdomain,  $this->languages_dir );
	}
	
	/**
	 * Fired when theme is activated
	 * 
	 * @since 1.0.0
	 * 
	 * @param string $old_name
	 * @param string $old_theme
	 */
	public function activate( $old_name, $old_theme ) {
		do_action( $this->prefix( 'activate' ), $old_name, $old_theme );
	}
	
	/**
	 * Fired when theme is deactivated
	 * 
	 * @since 1.0.0
	 * 
	 * @param string $new_name
	 * @param string $new_theme
	 */
	public function deactivate( $new_name, $new_theme ) {
		do_action( $this->prefix( 'deactivate' ), $new_name, $new_theme );
	}
	
	
	/** Set methods **************************************************/
	
	/**
	 * Set child theme
	 * 
	 * @since 1.0.0
	 */
	protected function set_child_theme( $is_child_theme = false ) {
		$this->is_child_theme = (bool) $is_child_theme;
	}
	
	
	/** Helper methods **************************************************/
	
	/**
	 * Check if theme is a child theme
	 * 
	 * @since 1.0.0
	 * 
	 * @return boolean
	 */
	public function is_child_theme() {
		return $this->is_child_theme;
	}
}
	
endif;