<?php
/**
 * Base class
 * 
 * @package 	TP Framework
 * @subpackage 	tp-framework\includes\classes
 * @since 		1.0.0
 * @author 		ThemePlugger <themeplugger@gmail.com>
 * @link 		http://themeplugger.com
 * @license 	GNU General Public License, version 3
 * @copyright 	© 2014 ThemePlugger
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

if ( ! class_exists( 'TP_Base' ) ) :

/**
 * TP_Base
 * 
 * @since 1.0.0
 * 
 * @abstract
 */
abstract class TP_Base implements TP_Interface_Singleton {
	
	/**
	 * Unique identifier
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $id;
	
	/**
	 * Base name
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $name;
	
	/**
	 * Base prefix
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $prefix;
	
	/**
	 * Base current version
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $version;
	
	/**
	 * Base textdomain
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $textdomain;
	
	/**
	 * Class name
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $class;
	
	/**
	 * Relative file
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $file;
	
	/**
	 * Base directory path
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $base_dir;
	
	/**
	 * Base directory URL
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $base_url;
	
	/**
	 * Base includes directory path
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $includes_dir;
	
	/**
	 * Base includes directory URL
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $includes_url;
	
	/**
	 * Base languages directory path
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $languages_dir;
	
	/**
	 * Base languages directory URL
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $languages_url;
	
	/**
	 * Base libraries directory path
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $libraries_dir;
	
	/**
	 * Base libraries directory URL
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $libraries_url;
	
	/**
	 * Base plugins directory path
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $plugins_dir;
	
	/**
	 * Base plugins directory URL
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $plugins_url;
	
	/**
	 * Base admin directory path
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $admin_dir;
	
	/**
	 * Base admin directory URL
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $admin_url;
	
	/**
	 * Base public directory path
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $public_dir;
	
	/**
	 * Base public directory URL
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $public_url;
	
	/**
	 * Admin
	 * 
	 * @since 1.0.0
	 * 
	 * @var object TP_Layer_Admin
	 */
	public $admin;
	
	/**
	 * Public
	 * 
	 * @since 1.0.0
	 * 
	 * @var object TP_Layer_Public
	 */
	public $public;
	
	/**
	 * Base data
	 * 
	 * @since 1.0.0
	 * 
	 * @todo For future use but not in used in @version 1.0.0
	 * 
	 * @var array
	 */
	public $data = array();
	 
	
	/**
	 * Singleton
	 * 
	 * @since 1.0.0
	 * 
	 * @return object One true instance of class object
	 */
	public static function init() {}
	
	
	/** Magic methods **************************************************/
	
	/**
	 * Constructor
	 * 
	 * @since 1.0.0
	 */
	protected function __construct() {}

	/**
	 * A dummy magic method to prevent this class from being cloned
	 *
	 * @since 1.0.0
	 */
	public function __clone() {
		 _doing_it_wrong( __FUNCTION__, __( 'Cheatin&#8217; huh?', 'tp_framework' ), '1.0.0' ); 
	}

	/**
	 * A dummy magic method to prevent this class from being unserialized
	 *
	 * @since 1.0.0
	 */
	public function __wakeup() {
		 _doing_it_wrong( __FUNCTION__, __( 'Cheatin&#8217; huh?', 'tp_framework' ), '1.0.0' ); 
	}

	/**
	 * Magic method for checking the existence of a certain custom field
	 *
	 * @since 1.0.0
	 */
	public function __isset( $key ) {
		 return isset( $this->data[$key] ); 
	}

	/**
	 * Magic method for getting class variables
	 *
	 * @since 1.0.0
	 */
	public function __get( $key ) {
		 return isset( $this->data[$key] ) ? $this->data[$key] : null; 
	}

	/**
	 * Magic method for setting class variables
	 *
	 * @since 1.0.0
	 */
	public function __set( $key, $value ) {
		 $this->data[$key] = $value; 
	}

	/**
	 * Magic method for unsetting class variables
	 *
	 * @since @since 1.0.0
	 */
	public function __unset( $key ) {
		 if ( isset( $this->data[$key] ) ) 
		 	unset( $this->data[$key] ); 
	}

	/**
	 * Magic method to prevent notices and errors from invalid method calls
	 *
	 * @since @since 1.0.0
	 */
	public function __call( $name = '', $args = array() ) {
		 unset( $name, $args ); 
		 return null; 
	}
	
	
	/** Setup methods **************************************************/
	
	/**
	 * Installation
	 * 
	 * @since 1.0.0
	 */
	protected function install() {}
	
	/**
	 * Uninstallation
	 * 
	 * @since 1.0.0
	 */
	protected function uninstall() {}
	
	/**
	 * Setup dependencies
	 * 
	 * @since 1.0.0
	 */
	protected function setup_dependencies() {}
	
	/**
	 * Setup the global variables
	 * 
	 * @since 1.0.0
	 */
	protected function setup_variables() {}
	
	/**
	 * Setup the included files
	 * 
	 * @since 1.0.0
	 */
	protected function setup_includes() {}
	
	/**
	 * Setup action and filter hooks
	 * 
	 * @since 1.0.0
	 */
	protected function setup_hooks() {}
	
	/**
	 * Setup language textdomain
	 * 
	 * @since 1.0.0
	 * 
	 * @param string 	$tag 			'init'
	 * @param string 	$function 		array( $this, 'load_textdomain' )
	 * @param int 	 	$priority 		10
	 * @param int 	 	$accepted_args 	1
	 */
	protected function setup_textdomain( $tag = 'init', $function = '', $priority = 10, $accepted_args = 1 ) {
		add_action( $tag ? $tag : 'init', $function ? $function : array( $this, 'load_textdomain' ), $priority, $accepted_args );
	}
	
	/**
	 * Sets up activation hook
	 * 
	 * @since 1.0.0
	 * 
	 * @abstract
	 */
	abstract protected function setup_activation();
	
	/**
	 * Sets up deactivation hook
	 * 
	 * @since 1.0.0
	 * 
	 * @abstract
	 */
	abstract protected function setup_deactivation();
	
	/**
	 * Sets up WPMU-environment
	 * 
	 * @since 1.0.0
	 */
	protected function setup_wpmu() {}
	
	
	/** Hook methods **************************************************/
	
	/**
	 * Activation
	 * 
	 * @since 1.0.0
	 */
	public function activate() {}
	
	/**
	 * Deactivation
	 * 
	 * @since 1.0.0
	 */
	public function deactivate() {}
	
	/**
	 * Load text domain for translation
	 * 
	 * @since 1.0.0
	 * 
	 * @abstract
	 */
	abstract public function load_textdomain();
	
	
	/** Set methods **************************************************/
	
	/**
	 * Sets unique identifier
	 * 
	 * @since 1.0.0
	 * 
	 * @access protected
	 * 
	 * @param string $id
	 */
	protected function set_id( $id ) {
		$this->id = $id;
	}
	
	/**
	 * Sets name
	 * 
	 * @since 1.0.0
	 * 
	 * @access protected
	 * 
	 * @param string $name
	 */
	protected function set_name( $name ) {
		$this->name = $name;
	}
	
	/**
	 * Sets prefix
	 * 
	 * @since 1.0.0
	 * 
	 * @access protected
	 * 
	 * @param string $prefix
	 */
	protected function set_prefix( $prefix ) {
		// Remove "underscore"
		$prefix = rtrim( $prefix, '_' );
		
		// Append "underscore"
		$prefix = $prefix . '_';
		
		$this->prefix = $prefix;
	}
	
	/**
	 * Sets current version
	 * 
	 * @since 1.0.0
	 * 
	 * @access protected
	 * 
	 * @param string $version
	 */
	protected function set_version( $version ) {
		$this->version = $version;
	}
	
	/**
	 * Sets language textdomain
	 * 
	 * @since 1.0.0
	 * 
	 * @access protected
	 * 
	 * @param string $textdomain
	 */
	protected function set_textdomain( $textdomain ) {
		$this->textdomain = $textdomain;
	}
	
	/**
	 * Sets class name
	 * 
	 * @since 1.0.0
	 * 
	 * @access protected
	 * 
	 * @param string $class
	 */
	protected function set_class( $class ) {
		$this->class = $class;
	}
	
	/**
	 * Sets relative file
	 * 
	 * @since 1.0.0
	 * 
	 * @access protected
	 * 
	 * @param string $file
	 */
	protected function set_file( $file ) {
		$this->file = $file;
	}
	
	/**
	 * Sets base directory path
	 * 
	 * @since 1.0.0
	 * 
	 * @access protected
	 * 
	 * @param string $base_dir
	 */
	protected function set_base_dir( $base_dir = '' ) {
		if ( empty( $base_dir ) ) {
			$base_dir = dirname( $this->file );
		}
		
		// Base root directory path
		$this->base_dir 		= tp_trailingslashit( $base_dir 					);
		
		// Base includes directory path
		$this->includes_dir 	= tp_trailingslashit( $this->base_dir . 'includes' 	);
		
		// Base languages directory path
		$this->languages_dir 	= tp_trailingslashit( $this->base_dir . 'languages' );
		
		// Base libraries directory path
		$this->libraries_dir 	= tp_trailingslashit( $this->base_dir . 'libraries' );
		
		// Base plugins directory path
		$this->plugins_dir 		= tp_trailingslashit( $this->base_dir . 'plugins' 	);
		
		// Base admin directory path
		$this->admin_dir 		= tp_trailingslashit( $this->base_dir . 'admin' 	);
		
		// Base public directory path
		$this->public_dir 		= tp_trailingslashit( $this->base_dir . 'public' 	);
	}
	
	/**
	 * Sets base directory URL
	 * 
	 * @since 1.0.0
	 * 
	 * @access protected
	 * 
	 * @param string $base_url
	 */
	protected function set_base_url( $base_url = '' ) {
		if ( empty( $base_url ) ) {
			
			// Check if plugin is included in a theme directory
			if ( wp_normalize_path( plugin_basename( $this->file ) ) == wp_normalize_path( $this->file ) ) {
				$base_url = get_template_directory_uri() . str_replace( wp_normalize_path( TEMPLATEPATH ), '', wp_normalize_path( $this->base_dir ) );
			} 
			// Assuming that plugin is included in a plugin directory
			else {
				$base_url = plugins_url( null, $this->file );
				
			}
		}
		
		// Base root directory URL
		$this->base_url 		= tp_trailingslashit( $base_url 					);
		
		// Base includes directory URL
		$this->includes_url 	= tp_trailingslashit( $this->base_url . 'includes' 	);
		
		// Base languages directory URL
		$this->languages_url 	= tp_trailingslashit( $this->base_url . 'languages' );
		
		// Base libraries directory URL
		$this->libraries_url 	= tp_trailingslashit( $this->base_url . 'libraries' );
		
		// Base plugins directory URL
		$this->plugins_url 		= tp_trailingslashit( $this->base_url . 'plugins' 	);
		
		// Base admin directory URL
		$this->admin_url 		= tp_trailingslashit( $this->base_url . 'admin' 	);
		
		// Base public directory URL
		$this->public_url 		= tp_trailingslashit( $this->base_url . 'public' 	);
	}
	
	
	/** Helper methods **************************************************/
	
	/**
	 * Attach prefix to the string
	 * 
	 * Prefix: tp_embed_
	 * String: _activate|activate
	 * Result: tp_embed_activate
	 * 
	 * @since 1.0.0
	 * 
	 * @param 	string 	$string
	 * @return 	string	$prefixed
	 */
	public function prefix( $string, $dashes = false ) {
		$prefixed = '';
		
		// Remove "underscore" at the beginning
		$string = ltrim( $string, '_' );
		
		// Prefix + String
		$prefixed = "{$this->prefix}{$string}";
		
		// "Dashes" instead of "underscores"
		if ( $dashes == true )
			$prefixed = str_replace( '_', '-', $prefixed );
		
		return $prefixed;
	}
}
	
endif; 
