<?php
/**
 * Hook action class
 * 
 * This class will handle the creation of newly created 
 * action that is hooked into an existing WordPress action.
 * 
 * Usage:
 * 
 * $hook_action = new TP_Hook_Action();
 * $hook_action->set_prefix( 'tp_framework_' );
 * $hook_action->add_action( 'init', 'init', 10 );
 * 
 * A new action will be created "tp_framework_init" which is 
 * hooked into "init" WordPress action.
 * 
 * @package 	TP Framework
 * @subpackage 	tp-framework\includes\classes
 * @since 		1.0.0
 * @author 		ThemePlugger <themeplugger@gmail.com>
 * @link 		http://themeplugger.com
 * @license 	GNU General Public License, version 3
 * @copyright 	© 2014 ThemePlugger
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

if ( ! class_exists( 'TP_Hook_Action' ) ) : 

/**
 * TP Hook Action
 * 
 * @since 1.0.0
 */
class TP_Hook_Action extends TP_Hook {
	
	/**
	 * Add dynamic action
	 * 
	 * @since 1.0.0
	 * 
	 * @uses add_action()
	 * 
	 * @param 	string 	$tag
	 * @param 	string 	$function
	 * @param 	int 	$priorty 		10
	 * @param 	int 	$accepted_args 	1
	 * @return 	void
	 */
	public function add_action( $tag, $function, $priority = 10, $accepted_args = 1 ) {
		add_action( $tag, array( $this, $function ), $priority, $accepted_args );
	}
	
	/**
	 * Call magic method
	 * 
	 * @since 1.0.0
	 * 
	 * @access 	protected
	 * 
	 * @param 	string 	$function
	 * @param 	array 	$function_args
	 * @return 	mixed
	 */
	public function __call( $function, $function_args = array() ) {
		do_action_ref_array( $this->prefix( $function ), $function_args );
	}
}

endif;
