<?php
/**
 * Hook filter class
 * 
 * This class will handle the creation of newly created 
 * filter that is hooked into an existing WordPress filter.
 * 
 * Usage:
 * 
 * $hook_filter = new TP_Hook_Filter();
 * $hook_filter->set_prefix( 'tp_framework_' );
 * $hook_filter->add_filter( 'template_include', 'init', 10, 2 );
 * 
 * A new filter will be created "tp_framework_template_include" which is 
 * hooked into "template_include" WordPress filter.
 * 
 * @package 	TP Framework
 * @subpackage 	tp-framework\includes\classes
 * @since 		1.0.0
 * @author 		ThemePlugger <themeplugger@gmail.com>
 * @link 		http://themeplugger.com
 * @license 	GNU General Public License, version 3
 * @copyright 	© 2014 ThemePlugger
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

if ( ! class_exists( 'TP_Hook_Filter' ) ) :

/**
 * TP Hook Filter
 * 
 * @since 1.0.0
 */
class TP_Hook_Filter extends TP_Hook {
	
	/**
	 * Add dynamic filter
	 * 
	 * @since 1.0.0
	 * 
	 * @uses add_filter()
	 * 
	 * @param 	string 	$tag
	 * @param 	string 	$function
	 * @param 	int 	$priorty 		10
	 * @param 	int 	$accepted_args 	1
	 * @return 	void
	 */
	public function add_filter( $tag, $function, $priority = 10, $accepted_args = 1 ) {
		add_filter( $tag, array( $this, $function ), $priority, $accepted_args );
	}
	
	/**
	 * Call magic method
	 * 
	 * @since 1.0.0
	 * 
	 * @access 	protected
	 * 
	 * @param 	string 	$function
	 * @param 	array 	$function_args
	 * @return 	mixed
	 */
	 
	public function __call( $function, $function_args = array() ) {
		return apply_filters_ref_array( $this->prefix( $function ), $function_args );
	}
}
	
endif;
