<?php
/**
 * Hook class
 * 
 * @package 	TP Framework
 * @subpackage 	tp-framework\includes\classes
 * @since 		1.0.0
 * @author 		ThemePlugger <themeplugger@gmail.com>
 * @link 		http://themeplugger.com
 * @license 	GNU General Public License, version 3
 * @copyright 	© 2014 ThemePlugger
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;
 
if ( ! class_exists( 'TP_Hook' ) ) :

/**
 * TP Hook
 * 
 * @since 1.0.0
 * 
 * @abstract
 */
abstract class TP_Hook {
	
	/**
	 * Prefix
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	protected $prefix;
	
	
	/** Magic methods **************************************************/
	
	/**
	 * Constructor
	 * 
	 * @since 1.0.0
	 * 
	 * @param 	string $prefix
	 * @return 	void
	 */
	public function __construct( $prefix = '' ) {
		$this->set_prefix( $prefix );
	}
	
	/**
	 * Caller
	 * 
	 * @since 1.0.0
	 * 
	 * @access 	protected
	 * @abstract
	 * 
	 * @param 	string 	$function
	 * @param 	array 	$function_args
	 * @return 	mixed
	 */
	abstract public function __call( $function, $function_args = array() );
	 
	
	/** Set methods **************************************************/
	
	/**
	 * Set prefix
	 * 
	 * @since 1.0.0
	 * 
	 * @param string $prefix
	 */
	public function set_prefix( $prefix ) {
		$this->prefix = $prefix;
	}
	
	
	/** Helper methods **************************************************/
	
	/**
	 * Attach prefix to the string
	 * 
	 * @since 	1.0.0
	 * 
	 * @uses 	tp_prefix()
	 * 
	 * @param 	string 	$string
	 * @return 	string
	 */
	protected function prefix( $string ) {
		return tp_prefix( $this->prefix, $string );
	}
}

endif;