<?php
/**
 * Admin layer class
 * 
 * @package 	TP Framework
 * @subpackage 	tp-framework\includes\classes
 * @since 		1.0.0
 * @author 		ThemePlugger <themeplugger@gmail.com>
 * @link 		http://themeplugger.com
 * @license 	GNU General Public License, version 3
 * @copyright 	© 2014 ThemePlugger
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

if ( ! class_exists( 'TP_Layer_Admin' ) ) : 

/**
 * TP Layer Admin
 * 
 * @todo register_meta_boxes()
 * @todo register_option_pages()
 * 
 * @since 1.0.0
 * 
 * @abstract
 */
abstract class TP_Layer_Admin extends TP_Layer {
	
	/**
	 * Admin directory path
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $admin_dir;
	
	/**
	 * Admin directory URL
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $admin_url;
	
	
	/** Setup methods **************************************************/
	
	/**
	 * Set up enqueue scripts hook
	 * 
	 * @since 1.0.0
	 * 
	 * @param string 	$tag 			'admin_enqueue_scripts'
	 * @param string 	$function 		array( $this, 'enqueue_scripts' )
	 * @param int 	 	$priority 		10
	 * @param int 	 	$accepted_args 	1
	 */
	protected function setup_enqueue_scripts( $tag = 'admin_enqueue_scripts', $function = '', $priority = 10, $accepted_args = 1 ) {
		if ( is_admin() ) {
			add_action( $tag ? $tag : 'admin_enqueue_scripts', $function ? $function : array( $this, 'enqueue_scripts' ), $priority, $accepted_args );
		}
	}


	/** Set methods **************************************************/
	
	/**
	 * Set up enqueue styles hook
	 * 
	 * @since 1.0.0
	 * 
	 * @param string 	$tag 			'admin_enqueue_scripts'
	 * @param string 	$function 		array( $this, 'enqueue_styles' )
	 * @param int 	 	$priority 		10
	 * @param int 	 	$accepted_args 	1
	 */
	protected function setup_enqueue_styles( $tag = 'admin_enqueue_scripts', $function = '', $priority = 10, $accepted_args = 1 ) {
		if ( is_admin() ) {
			add_action( $tag ? $tag : 'admin_enqueue_scripts', $function ? $function : array( $this, 'enqueue_styles' ), $priority, $accepted_args );
		}
	}
	
	/**
	 * Sets admin directory path
	 * 
	 * @since 1.0.0
	 * 
	 * @param string $admin_dir
	 */
	protected function set_admin_dir( $admin_dir ) {
		// Admin directory path
		$this->admin_dir = $admin_dir;
		
		// Admin assets directory path
		$this->assets_dir 	= tp_trailingslashit( $this->admin_dir . 'assets' 	);
		
		// Admin CSS directory path
		$this->css_dir 		= tp_trailingslashit( $this->assets_dir . 'css' 	);
		
		// Admin fonts directory path
		$this->fonts_dir 	= tp_trailingslashit( $this->assets_dir . 'fonts' 	);
		
		// Admin img directory path
		$this->img_dir 		= tp_trailingslashit( $this->assets_dir . 'img' 	);
		
		// Admin js directory path
		$this->js_dir 		= tp_trailingslashit( $this->assets_dir . 'js' 		);
	}
	
	/**
	 * Sets admin directory URL
	 * 
	 * @since 1.0.0
	 * 
	 * @param string $admin_url
	 */
	protected function set_admin_url( $admin_url ) {
		// Admin directory URL
		$this->admin_url = $admin_url;
		
		// Admin assets directory URL
		$this->assets_url 	= tp_trailingslashit( $this->admin_url . 'assets' 	);
		
		// Admin CSS directory URL
		$this->css_url 		= tp_trailingslashit( $this->assets_url . 'css' 	);
		
		// Admin fonts directory URL
		$this->fonts_url 	= tp_trailingslashit( $this->assets_url . 'fonts' 	);
		
		// Admin img directory URL
		$this->img_url 		= tp_trailingslashit( $this->assets_url . 'img' 	);
		
		// Admin js directory URL
		$this->js_url 		= tp_trailingslashit( $this->assets_url . 'js' 		);
	}
}
	
endif;
