<?php
/**
 * Public layer class
 * 
 * @package 	TP Framework
 * @subpackage 	tp-framework\includes\classes
 * @since 		1.0.0
 * @author 		ThemePlugger <themeplugger@gmail.com>
 * @link 		http://themeplugger.com
 * @license 	GNU General Public License, version 3
 * @copyright 	© 2014 ThemePlugger
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

if ( ! class_exists( 'TP_Layer_Public' ) ) : 
 
/**
 * TP Layer Public
 * 
 * @since 1.0.0
 * 
 * @abstract
 */
abstract class TP_Layer_Public extends TP_Layer {
	
	/**
	 * Public directory path
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $public_dir;
	
	/**
	 * Public directory URL
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $public_url;
	
	
	/** Setup methods **************************************************/
	
	/**
	 * Set up enqueue scripts hook
	 * 
	 * @since 1.0.0
	 * 
	 * @param string 	$tag 			'wp_enqueue_scripts'
	 * @param string 	$function 		array( $this, 'enqueue_scripts' )
	 * @param int 	 	$priority 		10
	 * @param int 	 	$accepted_args 	1
	 */
	protected function setup_enqueue_scripts( $tag = 'wp_enqueue_scripts', $function = '', $priority = 10, $accepted_args = 1 ) {
		add_action( $tag ? $tag : 'wp_enqueue_scripts', $function ? $function : array( $this, 'enqueue_scripts' ), $priority, $accepted_args );
	}
	
	/**
	 * Set up enqueue styles hook
	 * 
	 * @since 1.0.0
	 * 
	 * @param string 	$tag 			'wp_enqueue_scripts'
	 * @param string 	$function 		array( $this, 'enqueue_styles' )
	 * @param int 	 	$priority 		10
	 * @param int 	 	$accepted_args 	1
	 */
	protected function setup_enqueue_styles( $tag = 'wp_enqueue_scripts', $function = '', $priority = 10, $accepted_args = 1 ) {
		add_action( $tag ? $tag : 'wp_enqueue_scripts', $function ? $function : array( $this, 'enqueue_styles' ), $priority, $accepted_args );
	}
	
	
	/** Set methods **************************************************/
	
	/**
	 * Sets public directory path
	 * 
	 * @since 1.0.0
	 * 
	 * @param stirng $public_dir
	 */
	protected function set_public_dir( $public_dir ) {
		// Public directory path
		$this->public_dir = $public_dir;
		
		// Public assets directory path
		$this->assets_dir 	= tp_trailingslashit( $this->public_dir . 'assets' 	);
		
		// Public CSS directory path
		$this->css_dir 		= tp_trailingslashit( $this->assets_dir . 'css' 	);
		
		// Public fonts directory path
		$this->fonts_dir 	= tp_trailingslashit( $this->assets_dir . 'fonts' 	);
		
		// Public img directory path
		$this->img_dir 		= tp_trailingslashit( $this->assets_dir . 'img' 	);
		
		// Public js directory path
		$this->js_dir 		= tp_trailingslashit( $this->assets_dir . 'js' 		);
	}
	
	/**
	 * Sets public URL
	 * 
	 * @since 1.0.0
	 * 
	 * @param string $public_url
	 */
	protected function set_public_url( $public_url ) {
		// Public directory URL
		$this->public_url = $public_url;
		
		// Public assets directory URL
		$this->assets_url 	= tp_trailingslashit( $this->public_url . 'assets' 	);
		
		// Public CSS directory URL
		$this->css_url 		= tp_trailingslashit( $this->assets_url . 'css' 	);
		
		// Public fonts directory URL
		$this->fonts_url 	= tp_trailingslashit( $this->assets_url . 'fonts' 	);
		
		// Public img directory URL
		$this->img_url 		= tp_trailingslashit( $this->assets_url . 'img' 	);
		
		// Public js directory URL
		$this->js_url 		= tp_trailingslashit( $this->assets_url . 'js' 		);
	}
}

endif;