<?php
/**
 * Layer class
 * 
 * @package 	TP Framework
 * @subpackage 	tp-framework\includes\classes
 * @since 		1.0.0
 * @author 		ThemePlugger <themeplugger@gmail.com>
 * @link 		http://themeplugger.com
 * @license 	GNU General Public License, version 3
 * @copyright 	© 2014 ThemePlugger
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

if ( ! class_exists( 'TP_Layer' ) ) :

/**
 * TP Layer
 * 
 * @since 1.0.0
 * 
 * @abstract
 */
abstract class TP_Layer {
	
	/**
	 * Assets directory path
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $assets_dir;
	
	/**
	 * Assets directory URL
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $assets_url;
	
	/**
	 * CSS directory path
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $css_dir;
	
	/**
	 * CSS directory URL
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $css_url;
	
	/**
	 * Fonts directory path
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $fonts_dir;
	
	/**
	 * Fonts directory URL
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $fonts_url;
	
	/**
	 * IMG directory path
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $img_dir;
	
	/**
	 * IMG directory URL
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $img_url;
	
	/**
	 * JS directory path
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $js_dir;
	
	/**
	 * JS directory URL
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public $js_url;
	
	
	/** Setup methods **************************************************/
	
	/**
	 * Setup the global variables
	 * 
	 * @since 1.0.0
	 */
	protected function setup_variables() {}
	
	/**
	 * Setup the included files
	 * 
	 * @since 1.0.0
	 */
	protected function setup_includes() {}
	
	/**
	 * Setup action and filter hooks
	 * 
	 * @since 1.0.0
	 */
	protected function setup_hooks() {}
	
	/**
	 * Set up enqueue scripts hook
	 * 
	 * @since 1.0.0
	 * 
	 * @abstract
	 */
	abstract protected function setup_enqueue_scripts();
	
	/**
	 * Set up enqueue styles hook
	 * 
	 * @since 1.0.0
	 * 
	 * @abstract
	 */
	abstract protected function setup_enqueue_styles();
	
	
	/** Hook methods **************************************************/
	
	/**
	 * Enqueue scripts
	 * 
	 * @since 1.0.0
	 */
	public function enqueue_scripts() {}
	
	/**
	 * Enqueue styles
	 * 
	 * @since 1.0.0
	 */
	public function enqueue_styles() {}
}

endif;