<?php
/**
 * Shortcode class
 * 
 * @package 	TP Framework
 * @subpackage 	tp-framework\includes\classes
 * @since 		1.0.0
 * @author 		ThemePlugger <themeplugger@gmail.com>
 * @link 		http://themeplugger.com
 * @license 	GNU General Public License, version 3
 * @copyright 	© 2014 ThemePlugger
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

if ( ! class_exists( 'TP_Shortcode' ) ) :

/**
 * TP Shortcode
 * 
 * @since 1.0.0
 * 
 * @abstract
 */
abstract class TP_Shortcode {
	
	/** Magic methods **************************************************/
	
	/**
	 * Constructor
	 * 
	 * @since 1.0.0
	 * 
	 * @param 	string|array $tags
	 * @return 	void
	 */
	public function __construct( $tags = '' ) {
		global $shortcode_tags;
		
		if ( ! empty( $tags ) ) {
			if ( is_string( $tags ) ) {
				$tags = array( $tags );
			}
				
			if ( is_array( $tags ) && sizeof( $tags ) > 0 ) {
				foreach ( $tags as $tag ) {
					if ( ! isset( $shortcode_tags[$tag] ) ) {
						$this->add_shortcode( $tag );
					}
				}
			}
		}
	}
	
	
	/** Hook methods **************************************************/
	
	/**
	 * Shortcode callback
	 * 
	 * @since 1.0.0
	 * 
	 * @abstract
	 * 
	 * @param 	array 	$atts
	 * @param 	string 	$content
	 * @return 	void
	 */
	abstract public function shortcode( $atts, $content = null );
	
	
	/** API methods **************************************************/
	
	/**
	 * Add hook for shortcode tag
	 * 
	 * @since 1.0.0
	 * 
	 * @uses add_shortcode()
	 * 
	 * @param 	string 	$tag
	 * @param 	string 	$function
	 * @return 	void
	 */
	public function add_shortcode( $tag, $function = '' ) {
		add_shortcode( $tag, $function ? $function : array( $this, 'shortcode' ) );
	}
}

endif;
