<?php
/**
 * Widget class
 * 
 * @package 	TP Framework
 * @subpackage 	tp-framework\includes\classes
 * @since 		1.0.0
 * @author 		ThemePlugger <themeplugger@gmail.com>
 * @link 		http://themeplugger.com
 * @license 	GNU General Public License, version 3
 * @copyright 	© 2014 ThemePlugger
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

if ( class_exists( 'WP_Widget' ) && ! class_exists( 'TP_Widget' ) ) :
	
/**
 * TP Widget
 * 
 * @since 1.0.0
 * 
 * @abstract
 */
abstract class TP_Widget extends WP_Widget {
	
	/**
	 * Widgets
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	public static $widgets = array();
	
	/**
	 * Default arguments
	 * 
	 * @since 1.0.0
	 * 
	 * @var string
	 */
	protected $default_args = array();
	
	
	/**
	 * Register widget into WordPress Widget API
	 * 
	 * @since 1.0.0
	 */
	public static function register_widget( $class ) {
		self::$widgets[] = $class;
		
		// Attach it to WordPress action hook in 'widgets init'
		add_action( 'widgets_init', array( __CLASS__, 'register_widgets' ) );
	}
	
	/**
	 * Register widgets
	 * 
	 * @since 1.0.0
	 * 
	 * @uses register_widget()
	 */
	public static function register_widgets() {
		foreach ( self::$widgets as $widget ) {
			register_widget( $widget );
		}
	}
	
	/**
	 * Widget
	 * 
	 * @since 1.0.0
	 * 
	 * @param 	array $args
	 * @param 	array $instance
	 * @return 	void
	 */
	public function widget( $args, $instance ) {
		$instance = wp_parse_args( $instance, $this->default_args );

		extract( $args );

		echo $before_widget;

		$title = apply_filters( 'widget_title', isset( $instance['title'] ) ? $instance['title'] : '', $instance, $this->id_base );

		if ( ! empty( $title ) )
			echo $before_title . $title . $after_title;

		$this->content( $instance );

		echo $after_widget;
	}
	
	/**
	 * Widget content
	 * 
	 * @since 1.0.0
	 * 
	 * @param 	object $instance
	 * @return 	void
	 */
	public function content( $instance ) {}
	
	/**
	 * Update
	 * 
	 * @since 1.0.0
	 * 
	 * @param 	array $new_instance
	 * @param 	array $old_instance
	 * @return 	array $instance
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = $new_instance;
		return $instance;
	}
	
	/**
	 * Form
	 * 
	 * @since 1.0.0
	 * 
	 * @param 	array $instance
	 * @return 	void
	 */
	public function form( $instance ) {}
}
	
endif;