<?php
/**
 * Common functions
 * 
 * @package 	TP Framework
 * @subpackage 	tp-framework\includes\helpers
 * @since 		1.0.0
 * @author 		ThemePlugger <themeplugger@gmail.com>
 * @link 		http://themeplugger.com
 * @license 	GNU General Public License, version 3
 * @copyright 	© 2014 ThemePlugger
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

if ( ! function_exists( 'tp_define' ) ) :

/**
 * Define constants if it doesn't exist yet
 * 
 * @since 1.0.0
 * 
 * @param 	string 	$name
 * @param 	mixed 	$value
 * @param 	bool 	$case_insensitive
 */
function tp_define( $name, $value, $case_insensitive = false ) {
	if ( ! defined( $name ) )
		define( $name, $value, $case_insensitive );
}
	
endif;

if ( ! function_exists( 'tp_print_r' ) ) :

/**
 * Output object wrapped in <pre> tag
 * 
 * @since 1.0.0
 * 
 * @param 	mixed $object
 * @return 	void
 */
function tp_print_r( $object ) {
	echo '<pre>';
		print_r( $object );
	echo '</pre>';
}
	
endif;


/** WordPress **/

if ( ! function_exists( 'tp_get_current_url' ) ) :

/**
 * Retrieve current full URL
 * 
 * @since 1.0.0
 * 
 * @return string
 */
function tp_get_current_url() {
	return ( is_ssl() ? 'https://' : 'http://' ) . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'];
}

endif;

if ( ! function_exists( 'tp_is_parent_theme' ) ) :

/**
 * Check if file path is part of the current parent theme
 * 
 * @since 1.0.0
 * 
 * @param 	string 	$file
 * @return 	boolean	$is_parent_theme
 */
function tp_is_parent_theme( $file ) {
	$is_parent_theme = false;
	
	if ( strpos( tp_sanitize_path( $file ), tp_sanitize_path( get_template_directory() ) ) !== false ) {
		$is_parent_theme = true;
	}
	
	return $is_parent_theme;
}
	
endif;

if ( ! function_exists( 'tp_is_child_theme' ) ) :
	
/**
 * Check if file path is part of the current child theme
 * 
 * @since 1.0.0
 * 
 * @param 	string 	$file
 * @return 	boolean	$is_child_theme
 */
function tp_is_child_theme( $file ) {
	$is_child_theme = false;
	
	if ( strpos( tp_sanitize_path( $file ), tp_sanitize_path( get_stylesheet_directory() ) ) !== false ) {
		$is_child_theme = true;
	}
	
	return $is_child_theme;
}
	
endif;

if ( ! function_exists( 'tp_is_theme' ) ) :

/**
 * Check if file path is part of the current parent or child theme
 * 
 * @since 1.0.0
 * 
 * @param 	string 	$file
 * @return 	boolean $is_theme
 */
function tp_is_theme( $file ) {
	$is_theme = false;
	
	if ( tp_is_parent_theme( $file ) == true || tp_is_child_theme( $file ) == true ) {
		$is_theme = true;
	}
	
	return $is_theme;
}
	
endif;
