<?php
/**
 * Formatting functions
 * 
 * @package 	TP Framework
 * @subpackage 	tp-framework\includes\helpers
 * @since 		1.0.0
 * @author 		ThemePlugger <themeplugger@gmail.com>
 * @link 		http://themeplugger.com
 * @license 	GNU General Public License, version 3
 * @copyright 	© 2014 ThemePlugger
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

if ( ! function_exists( 'tp_sanitize_path' ) ) :
	
/**
 * Sanitize path
 * 
 * @uses Adapted from Redux_Helpers
 * 
 * @since 1.0.0
 * 
 * @param string $path
 * @return string $path
 */
function tp_sanitize_path( $path ) {
	$path = str_replace( '', '', str_replace( array( "\\", "\\\\" ), '/', $path ) );
	
	if ( $path[ strlen( $path ) - 1 ] === '/' ) {
		$path = rtrim( $path, '/' );
	}

	return $path;
}

endif;

if ( ! function_exists( 'tp_trailingslashit' ) ) :

/**
 * Add proper trailing slash for both
 * backward and forward slashes.
 * 
 * @since 1.0.0
 * 
 * @uses trailingslashit()
 * @uses wp_normalize_path() - Problem: Converts "//" to "/" causing http:// to be "http:/".
 * 
 * @param string $string
 * @return string $string
 */
function tp_trailingslashit( $string ) {
	$string = trailingslashit( $string );
	
	// Correct initial directory paths that uses backslashes
	if ( strpos( $string, DIRECTORY_SEPARATOR ) !== false ) {
		$string = str_replace( '/', DIRECTORY_SEPARATOR, $string );
	}
	
	return $string;
}
	
endif;

if ( ! function_exists( 'tp_untrailingslashit' ) ) :

/**
 * Removes backward or forward slashes
 * 
 * Add an opposite function for tp_trailingslashit()
 * 
 * @since 1.0.0
 * 
 * @uses untrailingslashit()
 * 
 * @param string $string
 * @return string $string
 */
function tp_untrailingslashit( $string ) {
	return untrailingslashit( $string );
}
	
endif;

if ( ! function_exists( 'tp_prefix' ) ) :
	
/**
 * Attach prefix to the string
 * 
 * Prefix: tp_embed_
 * String: _activate|activate
 * Result: tp_embed_activate
 * 
 * @since 1.0.0
 * 
 * @param 	string 	$string
 * @return 	string
 */
function tp_prefix( $prefix, $string ) {
	// Remove "underscore" at the beginning
	$string = ltrim( $string, '_' );
	
	return "{$prefix}{$string}";
}
	
endif;
