<?php
/**
 * TP Framework
 * 
 * @package 	TP Framework
 * @version 	1.0.0
 * @author 		ThemePlugger <themeplugger@gmail.com>
 * @link 		http://themeplugger.com
 * @license 	GNU General Public License, version 3
 * @copyright 	© 2014 ThemePlugger
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Include important files!
 * 
 * @since 1.0.0
 */
/* if ( ! class_exists( 'TP_Framework' ) ) */ {
	
	// Load helpers
	foreach ( glob( dirname( __FILE__ ) . '/includes/helpers/*.php' ) as $helper ) {
		require_once( $helper );
	}
	
	// Load autoload class
	require_once( dirname( __FILE__ ) . '/includes/classes/autoload.php' 	);
	
	// Register an autoload for TP Framework classes
	if ( file_exists( $includes_dir = dirname( __FILE__ ) . '/includes/classes' ) ) {
		TP_Autoload::register( 'TP_', $includes_dir );
	}
	
	// Register an autoload for TP Framework public classes
	if ( file_exists( $public_dir = dirname( __FILE__ ) . 'public/classes' ) ) {
		TP_Autoload::register( 'TP_', $public_dir );
	}
	
	// Register an autoload for TP Framework admin classes
	if ( is_admin() && file_exists( $admin_dir = dirname( __FILE__ ) . '/admin/classes' ) ) {
		TP_Autoload::register( 'TP_', $admin_dir );
	}
}


if ( ! class_exists( 'TP_Framework' ) ) :

/**
 * TP Framework
 * 
 * @since 1.0.0
 */
final class TP_Framework extends TP_Base_Plugin {
	
	/**
	 * Singleton
	 * 
	 * @since 1.0.0
	 * 
	 * @return object One true instance of TP_Framework object
	 */
	public static function init() {
		static $instance = null;
		
		if ( $instance === null ) {
			$instance = new self();
			$instance->setup_variables();
			$instance->setup_includes();
			$instance->setup_hooks();
		}
		
		return $instance;
	}
	
	/**
	 * Setup the global variables
	 * 
	 * @since 1.0.0
	 */
	protected function setup_variables() {
		// Plugin unique identifier
		$this->set_id( 'tp-framework' );
		
		// Plugin name
		$this->set_name( 'TP Framework' );
		
		// Plugin prefix
		$this->set_prefix( 'tp_framework_' );
		
		// Plugin version
		$this->set_version( '1.0.0' );
		
		// Plugin textdomain
		$this->set_textdomain( 'tp_framework' );
		
		// Plugin class name
		$this->set_class( __CLASS__ );
		
		// Plugin relative file
		$this->set_file( __FILE__ );
		
		// Plugin base directory paths
		$this->set_base_dir();
		
		// Plugin base directory URLs
		$this->set_base_url();
	}
	
	/**
	 * Setup the included files
	 * 
	 * @since 1.0.0
	 */
	protected function setup_includes() {
		require_once( $this->public_dir . 'public.php' );
		
		if ( is_admin() ) {
			require_once( $this->admin_dir . 'admin.php' );
		}
	}
	
	/**
	 * Setup action and filter hooks
	 * 
	 * @since 1.0.0
	 */
	protected function setup_hooks() {
		
		// Disabled some setup methods
		// because we are not planning to
		// initiate this as a plugin but
		// rather a library.
		
		// Setup activation hook
		// $this->setup_activation();
		
		// Setup deactivation hook
		// $this->setup_deactivation();
			
		// Setup WPMU
		// $this->setup_wpmu();
		
		// Setup language text domain
		$this->setup_textdomain();
	}
}
endif;

if ( ! function_exists( 'tp_framework' ) && class_exists( 'TP_Framework' ) ) :

/**
 * TP Framework function
 * 
 * @since 1.0.0
 * 
 * @return object One true instance of TP_Framework object
 */
function tp_framework() {
	return TP_Framework::init();
}
	
endif;

/**
 * Globalize
 * 
 * @since 1.0.0
 */
global $tp_framework;

/**
 * Initiliaze TP Framework
 * 
 * @since 1.0.0
 */
$tp_framework = tp_framework();