<?php
/**
 * WooCommerce Availability Notifications
 * 
 * Plugin Name: WooCommerce Availability Notifications
 * Plugin URI: 	http://themeplugger.com/products/woocommerce-availability-notifications
 * Description: Enables your WooComerce to have customized stock availability notifications.
 * Author:  	ThemePlugger
 * Author URI: 	http://themeplugger.com
 * Version: 	1.0.3
 * Text Domain: wc_availability_notifications
 * License: 	GPL3+
 * License URI: http://www.gnu.org/licenses/gpl-3.0.txt
 * Domain Path: /languages
 * 
 * @package 	WooCommerce Availability Notifications
 * @version 	1.0.3
 * @author  	ThemePlugger <themeplugger@gmail.com>
 * @link     	http://themeplugger.com
 * @license 	GNU General Public License, version 3
 * @copyright 	2014 ThemePlugger
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * TP Framework
 * 
 * @since 	WooCommerce Availability Notifications 	1.0.3
 * @version TP Framework 							1.0.0
 */
require_once( dirname( __FILE__ ) . '/tp-framework/tp-framework.php' );


if ( ! class_exists( 'WC_Availability_Notifications' ) ) :

/**
 * WooCommerce Availability Notifications
 * 
 * @since 1.0.3
 */
final class WC_Availability_Notifications extends TP_Base_Plugin {
	
	/**
	 * Singleton
	 * 
	 * @since 1.0.3
	 * 
	 * @return object One true instance of WC_Availability_Notifications object
	 */
	public static function init() {
		static $instance = null;
		
		if ( $instance === null ) {
			$instance = new self();
			$instance->setup_variables();
			$instance->setup_dependencies();
			$instance->setup_includes();
			$instance->setup_hooks();
		}
		
		return $instance;
	}
	
	/**
	 * Setup dependencies
	 * 
	 * @since 1.0.3
	 */
	protected function setup_dependencies() {
		if ( ! function_exists( 'is_woocommerce_active' ) ) {
			require_once( tp_framework()->libraries_dir . 'woocommerce/wc-functions.php' );
		}
		
		if ( ! is_woocommerce_active() ) {
			sprintf( __( 'Hey there! This plugin requires <a target="_blank" href="%s">WooCommerce</a> 1.6.6 or greater (and prefers the latest version - 2.x!). Please install and/or activate it first!', 'wc_availability_notifications' ), admin_url( 'plugin-install.php?tab=search&s=woocommerce' ) );
		}
	}
	
	/**
	 * Setup the global variables
	 * 
	 * @since 1.0.3
	 */
	protected function setup_variables() {
		// Plugin unique identifier
		$this->set_id( 'wc-availability-notifications' );
		
		// Plugin name
		$this->set_name( 'WooCommerce Availability Notifications' );
		
		// Plugin prefix
		$this->set_prefix( 'wc_availability_notifications_' );
		
		// Plugin version
		$this->set_version( '1.0.3' );
		
		// Plugin textdomain
		$this->set_textdomain( 'wc_availability_notifications' );
		
		// Plugin class name
		$this->set_class( __CLASS__ );
		
		// Plugin relative file
		$this->set_file( __FILE__ );
		
		// Plugin base directory paths
		$this->set_base_dir();
		
		// Plugin base directory URLs
		$this->set_base_url();
	}
	
	/**
	 * Setup the included files
	 * 
	 * @since 1.0.3
	 */
	protected function setup_includes() {
		
		// Include important files
		require_once( $this->includes_dir . 'functions.php' 	);
		require_once( $this->includes_dir . 'shortcodes.php' 	);
		
		// Public-facing
		require_once( $this->public_dir . 'public.php' 		);
		
		// Admin-facing
		if ( is_admin() ) {
			require_once( $this->admin_dir . 'admin.php' 	);
		}
	}
	
	/**
	 * Setup action and filter hooks
	 * 
	 * @since 1.0.3
	 */
	protected function setup_hooks() {
		// Setup activation hook
		$this->setup_activation();
		
		// Setup deactivation hook
		$this->setup_deactivation();
			
		// Setup WPMU
		$this->setup_wpmu();
		
		// Setup language text domain
		$this->setup_textdomain();
	}
}
	
endif;

if ( ! function_exists( 'wc_availability_notifications' ) && class_exists( 'WC_Availability_Notifications' ) ) :

/**
 * Singleton function
 * 
 * @since 1.0.3
 * 
 * @return object One true instance of WC_Availability_Notifications object
 */
function wc_availability_notifications() {
	return WC_Availability_Notifications::init();
}

endif;

/**
 * Globalize
 * 
 * @since 1.0.3
 */
global $wc_availability_notifications;

/**
 * Initiliaze
 * 
 * @since 1.0.3
 */
$wc_availability_notifications = wc_availability_notifications();